Flask-MDE: Pagedown for Flask
=============================

Release v1.1.0

.. image:: https://img.shields.io/pypi/v/flask_mde
    :target: https://pypi.org/project/flask_mde/
    
.. image:: https://img.shields.io/pypi/l/flask_mde
    :target: https://pypi.org/project/flask_mde/

.. image:: https://img.shields.io/pypi/pyversions/flask_mde
    :target: https://pypi.org/project/flask_mde/

.. image:: https://readthedocs.org/projects/flask-mde/badge/?version=latest
    :target: https://flask-mde.readthedocs.io/en/latest/?badge=latest

-------------------

`Pagedown <https://github.com/StackExchange/pagedown>`_ Editor with
`Google code-prettify <https://github.com/google/code-prettify>`_ for 
`Flask <https://palletsprojects.com/p/flask/>`_. 
`WTForms <https://wtforms.readthedocs.io/en/stable/index.html>`_ integration supported.

Pagedown is a Markdown editor and previewer popularised by its use on 
`StackOverflow <https://stackoverflow.com/>`_. You can use the *Flask-MDE* extension 
to integrate the Pagedown editor into your Flask application.

Read the `User Guide <https://flask-mde.readthedocs.io/en/latest/user-guide.html>`_ to get started.

.. image:: https://raw.githubusercontent.com/bittobennichan/Flask-MDE/master/assets/website.png
    :target: https://flask-mde.readthedocs.io/en/latest/index.html